#
#This file is part of smart-notifier, a graphical disk health notifier
#
#Copyright (C) 2005, 2006  Brian Sutherland <jinty@web.de>
#
#This program is free software; you can redistribute it and/or modify
#it under the terms of the GNU General Public License as published by
#the Free Software Foundation; either version 2 of the License, or
#(at your option) any later version.
#
#This program is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU General Public License for more details.
#
#You should have received a copy of the GNU General Public License
#along with this program; if not, write to the Free Software
#Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#

import dbus
import dbus.service
import dbus.glib # This **HIGHLY** unintuitive piece of code is to
                 # monkey patch some stuff and make other stuff work.
                 # Fun with capital F

# Globals
BUS = dbus.SystemBus()
SERVICE = "/smart_notifier/DbusService"
SERVICE_NAME = SERVICE.replace('/', '.')[1:]

UD_SERVICE = SERVICE + "/WarnUser"
UD_INTERFACE = SERVICE_NAME + ".WarnUser"

def notify(msg):
    bus_name = dbus.service.BusName(SERVICE_NAME, bus=BUS)
    object = WarnUser(bus_name, UD_SERVICE)
    object.warn_user(msg)


class WarnUser(dbus.service.Object):

    @dbus.service.signal(UD_INTERFACE)
    def warn_user(self, msg):
        pass



import os
from setuptools import setup, find_packages

def get_version():
    dir = os.path.dirname(__file__)
    fn = os.path.join(dir, 'src', 'smart_notifier', 'version.txt')
    f = open(fn, 'r')
    result = f.read()
    f.close()
    print result
    return result

# Setup SchoolTool
setup(
    name="smart_notifier",
    description="graphical hard disk health status notifier",
    long_description="""
A graphical notifier for smartmontools which attempts to show messages from
the smartd disk monitoring daemon to the user. Currently only for gtk.
.
WARNING: This package is not a replacement for regular backups. It will _try_
to warn the user when smartd sends a disk health warning. But success is not
guaranteed. At best this package is an extra layer of protection.
""",
    version=get_version(),
    url='http://lentejasverdes.ath.cx/svn/smart-notifier/',
    license="GPL",
    maintainer="Brian Sutherland",
    maintainer_email="jinty@web.de",
    platforms=["any"],
    package_dir={'': 'src'},
    package_data={'': ['*.glade', '*.txt']},
    scripts=['scripts/smart-notifier'],
    packages=find_packages('src'),
    zip_safe=False,
    )





#
#This file is part of smart-notifier, a graphical disk health notifier
#
#Copyright (C) 2005, 2006  Brian Sutherland <jinty@web.de>
#
#This program is free software; you can redistribute it and/or modify
#it under the terms of the GNU General Public License as published by
#the Free Software Foundation; either version 2 of the License, or
#(at your option) any later version.
#
#This program is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU General Public License for more details.
#
#You should have received a copy of the GNU General Public License
#along with this program; if not, write to the Free Software
#Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#

import os
import smart_notifier
import gtk # bletch, gtk import can fail if we do not have a GUI
import gtk.glade

here = os.path.dirname(__file__)
# Paths to glade files
warning_window = os.path.join(here, 'smart-notifier.glade')

def warn_user(msg):
    #Make the window
    ui = gtk.glade.XML(warning_window)
    #self.ui.signal_connect('end', gtk.main_quit)
    #Customize message
    textbuffer = gtk.TextBuffer()
    textbuffer.set_text(msg)
    textbox = ui.get_widget('textview1')
    textbox.set_buffer(textbuffer)
    # Fix the icon size XXX -- this is temporary intil gazpacho works
    icon = ui.get_widget('image1')
    icon.set_from_stock(gtk.STOCK_DIALOG_WARNING, gtk.ICON_SIZE_DIALOG)
    # Showit
    window = ui.get_widget('window1')
    window.show_all()

def service():
    smart_notifier.BUS.add_signal_receiver(warn_user,
                                           signal_name='warn_user',
                                           dbus_interface=smart_notifier.UD_INTERFACE,
                                           #named_service=smart_notifier.UD_SERVICE, - thiss fails
                                           path=smart_notifier.UD_SERVICE)
    gtk.main()
